==> lsh-0.9.7.tar.gz: lsh-0.9.7/acconfig.h <==
/* The name and version of this software distribution. These
 * originates from AM_INIT_AUTOMAKE in the configure.in file. */
#undef PACKAGE
#undef VERSION

/* Define to enable sanity checking on memory allocation and casting */
#undef DEBUG_ALLOC

/* Define to enable tracing */
#undef DEBUG_TRACE

/* Define if zlib should be used */
#undef WITH_ZLIB

/* Define if zlib.h is present */
#undef HAVE_ZLIB_H

/* Define to enable pty support */
#undef WITH_PTY_SUPPORT

/* Define to enable fallback to SSH1 */
#undef WITH_SSH1_FALLBACK

/* Location of the SSH1 daemon */
#undef SSHD1

/* Define if IDEA should be used */
#undef WITH_IDEA

/* Define to enable tcp forwarding */
#undef WITH_TCP_FORWARD

/* For Ipv6 support */
#undef WITH_IPV6

/* For utmp support */
#undef WITH_UTMP

/* Define to indicate that shutdown seems to work properly */
#undef SHUTDOWN_WORKS_WITH_UNIX_SOCKETS

/* Define if the compiler understands __attribute__ */
#undef HAVE_GCC_ATTRIBUTE

/* Define if the compiler understands __FUNCTION__ */
#undef HAVE_GCC_FUNCTION

/* Define if the compiler understands offsetof(TYPE, MEMBER) */
#undef HAVE_C_OFFSETOF

/* Define if a we have working UNIX98 pty handling */
#undef HAVE_UNIX98_PTYS

/* openpty() available? */
#undef HAVE_OPENPTY

/* For BSD-style pty allocation */
#undef PTY_BSD_SCHEME_FIRST_CHARS
#undef PTY_BSD_SCHEME_SECOND_CHARS

#undef PTY_BSD_SCHEME

/* syslog() available? */
#undef HAVE_SYSLOG

/* struct utmp has a ut_host member */
#undef HAVE_UT_HOST

/* struct utmp has a ut_addr member */
#undef HAVE_UT_ADDR

/* struct utmp has a ut_addr_v6 member */
#undef HAVE_UT_ADDR_V6

/* Length type used by getsockopt() */
#undef socklen_t

/* Define to support non-standard packets of ssh2 */
#undef DATAFELLOWS_WORKAROUNDS

/* Global variables needed by argp */
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME

/* Define to enable x11 forwarding */
#undef WITH_X11_FORWARD

/* Define to enable authentication agent forwarding */
#undef WITH_AGENT_FORWARD

#undef WITH_ALF

==> lsh-0.9.9.tar.gz: lsh-0.9.9/acconfig.h <==
/* The name and version of this software distribution. These
 * originates from AM_INIT_AUTOMAKE in the configure.in file. */
#undef PACKAGE
#undef VERSION

/* Define to enable sanity checking on memory allocation and casting */
#undef DEBUG_ALLOC

/* Define to enable tracing */
#undef DEBUG_TRACE

/* Define if zlib should be used */
#undef WITH_ZLIB

/* Define if zlib.h is present */
#undef HAVE_ZLIB_H

/* Define to enable pty support */
#undef WITH_PTY_SUPPORT

/* Define to enable fallback to SSH1 */
#undef WITH_SSH1_FALLBACK

/* Location of the SSH1 daemon */
#undef SSHD1

/* Define if IDEA should be used */
#undef WITH_IDEA

/* Define to enable tcp forwarding */
#undef WITH_TCP_FORWARD

/* For Ipv6 support */
#undef WITH_IPV6

/* For utmp support */
#undef WITH_UTMP

/* Define to indicate that shutdown seems to work properly */
#undef SHUTDOWN_WORKS_WITH_UNIX_SOCKETS

/* Define if the compiler understands __attribute__ */
#undef HAVE_GCC_ATTRIBUTE

/* Define if the compiler understands __FUNCTION__ */
#undef HAVE_GCC_FUNCTION

/* Define if the compiler understands offsetof(TYPE, MEMBER) */
#undef HAVE_C_OFFSETOF

/* Define if a we have working UNIX98 pty handling */
#undef HAVE_UNIX98_PTYS

/* openpty() available? */
#undef HAVE_OPENPTY

/* For BSD-style pty allocation */
#undef PTY_BSD_SCHEME_FIRST_CHARS
#undef PTY_BSD_SCHEME_SECOND_CHARS

#undef PTY_BSD_SCHEME

/* Define if GMP is available */
#undef HAVE_LIBGMP

/* syslog() available? */
#undef HAVE_SYSLOG

/* struct utmp has a ut_host member */
#undef HAVE_UT_HOST

/* struct utmp has a ut_name member */
#undef HAVE_UT_NAME

/* struct utmp has a ut_user member */
#undef HAVE_UT_USER

/* struct utmp has a ut_addr member */
#undef HAVE_UT_ADDR

/* struct utmp has a ut_addr_v6 member */
#undef HAVE_UT_ADDR_V6

/* Length type used by getsockopt() */
#undef socklen_t

/* Define to support non-standard packets of ssh2 */
#undef DATAFELLOWS_WORKAROUNDS

/* Global variables needed by argp */
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME

/* Define to enable x11 forwarding */
#undef WITH_X11_FORWARD

/* Define to enable authentication agent forwarding */
#undef WITH_AGENT_FORWARD

#undef WITH_ALF
